@@ -373,7 +373,7 @@ class NodeEditor:
             module_name = nodesrc[nodesrc.rfind("\\")+1:-3]
             try:
                 # get the module spec and import the module
-                mod = importlib.import_module("nodes."+module_name)
+                mod = importlib.import_module(("scNodes." if not cfg.frozen else "")+"nodes."+module_name)
                 impl = NodeImpl(mod.create)
                 if not impl.enabled:
                     continue
